<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id">
<context>
    <name>TaskbarFactory</name>
    <message>
        <location filename="../taskbarfactory.cpp" line="28"/>
        <source>Taskbar Plugin</source>
        <translation>Plugin Bilah Tugas</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="49"/>
        <source>About Taskbar Plugin</source>
        <translation>Tentang Plugin Bilah Tugas</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="50"/>
        <source>Qmmp Taskbar Plugin</source>
        <translation>Plugin Bilah Tugas Qmmp</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="51"/>
        <source>This plugin adds support for progress indicator in the Windows taskbar</source>
        <translation>Plugin ini menambahkan dukungan untuk indikator kemajuan dalam bilah tugas Windows</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Ditulis oleh: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="53"/>
        <source>Based on QtWinExtras module of the Qt Toolkit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="54"/>
        <source>QtWinExtras developers:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="55"/>
        <source>Ivan Vizir &lt;define-true-false@yandex.com&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="56"/>
        <source>The Qt Company Ltd.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
